@@ -128,25 +128,40 @@ static const GdkDebugKey gdk_debug_keys[] = {
   { "dmabuf",          GDK_DEBUG_DMABUF, "Information about dmabuf buffers" },
   { "offload",         GDK_DEBUG_OFFLOAD, "Information about subsurfaces and graphics offload" },
 
+  { "linear",          GDK_DEBUG_LINEAR, "Enable linear rendering" },
+  { "hdr",             GDK_DEBUG_HDR, "Force HDR rendering" },
   { "portals",         GDK_DEBUG_PORTALS, "Force use of portals" },
   { "no-portals",      GDK_DEBUG_NO_PORTALS, "Disable use of portals" },
-  { "gl-disable",      GDK_DEBUG_GL_DISABLE, "Disable OpenGL support" },
+  { "force-offload",   GDK_DEBUG_FORCE_OFFLOAD, "Force graphics offload for all textures" },
   { "gl-no-fractional", GDK_DEBUG_GL_NO_FRACTIONAL, "Disable fractional scaling for OpenGL" },
   { "gl-debug",        GDK_DEBUG_GL_DEBUG, "Insert debugging information in OpenGL" },
-  { "gl-disable-gl",   GDK_DEBUG_GL_DISABLE_GL, "Only allow OpenGL GLES API" },
-  { "gl-disable-gles", GDK_DEBUG_GL_DISABLE_GLES, "Don't allow OpenGL GLES API" },
   { "gl-prefer-gl",    GDK_DEBUG_GL_PREFER_GL, "Prefer GL over GLES API" },
-  { "gl-egl",          GDK_DEBUG_GL_EGL, "Use EGL on X11 or Windows" },
-  { "gl-glx",          GDK_DEBUG_GL_GLX, "Use GLX on X11" },
-  { "gl-wgl",          GDK_DEBUG_GL_WGL, "Use WGL on Windows" },
-  { "vulkan-disable",  GDK_DEBUG_VULKAN_DISABLE, "Disable Vulkan support" },
-  { "vulkan-validate", GDK_DEBUG_VULKAN_VALIDATE, "Load the Vulkan validation layer" },
   { "default-settings",GDK_DEBUG_DEFAULT_SETTINGS, "Force default values for xsettings" },
   { "high-depth",      GDK_DEBUG_HIGH_DEPTH, "Use high bit depth rendering if possible" },
   { "no-vsync",        GDK_DEBUG_NO_VSYNC, "Repaint instantly (uses 100% CPU with animations)" },
-  { "dmabuf-disable",  GDK_DEBUG_DMABUF_DISABLE, "Disable dmabuf support" },
 };
 
+static const GdkDebugKey gdk_feature_keys[] = {
+  { "gl",         GDK_FEATURE_OPENGL,           "Disable OpenGL support" },
+  { "gl-api",     GDK_FEATURE_GL_API,           "Disable non-GLES GL API" },
+  { "gles-api",   GDK_FEATURE_GLES_API,         "Disable GLES GL API" },
+  { "egl",        GDK_FEATURE_EGL,              "Disable EGL" },
+  { "glx",        GDK_FEATURE_GLX,              "Disable GLX" },
+  { "wgl",        GDK_FEATURE_WGL,              "Disable WGL" },
+  { "vulkan",     GDK_FEATURE_VULKAN,           "Disable Vulkan support" },
+  { "dmabuf",     GDK_FEATURE_DMABUF,           "Disable dmabuf support" },
+  { "offload",    GDK_FEATURE_OFFLOAD,          "Disable graphics offload" },
+  { "color-mgmt", GDK_FEATURE_COLOR_MANAGEMENT, "Disable color management" },
+};
+
+
+static GdkFeatures gdk_features;
+
+gboolean
+gdk_has_feature (GdkFeatures features)
+{
+  return (features & gdk_features) == features;
+}
 
 #ifdef G_HAS_CONSTRUCTORS
 #ifdef G_DEFINE_CONSTRUCTOR_NEEDS_PRAGMA
@@ -214,6 +229,7 @@ gdk_ensure_resources (void)
 
 guint
 gdk_parse_debug_var (const char        *variable,
+                     const char        *docs,
                      const GdkDebugKey *keys,
                      guint              nkeys)
 {
@@ -274,6 +290,7 @@ gdk_parse_debug_var (const char        *variable,
         max_width = MAX (max_width, strlen (keys[i].key));
       max_width += 4;
 
+      fprintf (stderr, "%s\n", docs);
       fprintf (stderr, "Supported %s values:\n", variable);
       for (i = 0; i < nkeys; i++) {
         fprintf (stderr, "  %s%*s%s\n", keys[i].key, (int)(max_width - strlen (keys[i].key)), " ", keys[i].help);
@@ -301,21 +318,26 @@ gdk_parse_debug_var (const char        *variable,
 void
 gdk_pre_parse (void)
 {
+  GdkFeatures disabled_features;
+
   gdk_initialized = TRUE;
 
   gdk_ensure_resources ();
 
   _gdk_debug_flags = gdk_parse_debug_var ("GDK_DEBUG",
-                                          gdk_debug_keys,
-                                          G_N_ELEMENTS (gdk_debug_keys));
+      "GDK_DEBUG can be set to values that make GDK print out different\n"
+      "types of debugging information or change the behavior of GDK for\n"
+      "debugging purposes.\n",
+      gdk_debug_keys,
+      G_N_ELEMENTS (gdk_debug_keys));
 
-  /* These are global */
-  if (_gdk_debug_flags & GDK_DEBUG_GL_EGL)
-    gdk_gl_backend_use (GDK_GL_EGL);
-  else if (_gdk_debug_flags & GDK_DEBUG_GL_GLX)
-    gdk_gl_backend_use (GDK_GL_GLX);
-  else if (_gdk_debug_flags & GDK_DEBUG_GL_WGL)
-    gdk_gl_backend_use (GDK_GL_WGL);
+  disabled_features = gdk_parse_debug_var ("GDK_DISABLE",
+      "GDK_DISABLE can be set to values which cause GDK to disable\n"
+      "certain features.\n",
+      gdk_feature_keys,
+      G_N_ELEMENTS (gdk_feature_keys));
+
+  gdk_features = GDK_ALL_FEATURES & ~disabled_features;
 
 #ifndef G_HAS_CONSTRUCTORS
   stash_and_unset_environment ();
