@@ -40,13 +40,6 @@ gdk_wayland_vulkan_context_create_surface (GdkVulkanContext *context,
   GdkSurface *surface = gdk_draw_context_get_surface (GDK_DRAW_CONTEXT (context));
   GdkDisplay *display = gdk_draw_context_get_display (GDK_DRAW_CONTEXT (context));
 
-  /* This is necessary so that Vulkan sees the Surface.
-   * Usually, vkCreateXlibSurfaceKHR() will not cause a problem to happen as
-   * it just creates resources, but further calls with the resulting surface
-   * do cause issues.
-   */
-  gdk_display_sync (display);
-
   return GDK_VK_CHECK (vkCreateWaylandSurfaceKHR, gdk_vulkan_context_get_instance (context),
                                                    &(VkWaylandSurfaceCreateInfoKHR) {
                                                        VK_STRUCTURE_TYPE_WAYLAND_SURFACE_CREATE_INFO_KHR,
@@ -64,10 +57,16 @@ gdk_vulkan_context_wayland_end_frame (GdkDrawContext *context,
                                       cairo_region_t *painted)
 {
   GdkSurface *surface = gdk_draw_context_get_surface (GDK_DRAW_CONTEXT (context));
+  GdkWaylandSurface *impl = GDK_WAYLAND_SURFACE (surface);
+  int dx = impl->pending_buffer_offset_x;
+  int dy = impl->pending_buffer_offset_y;
 
   gdk_wayland_surface_sync (surface);
   gdk_wayland_surface_request_frame (surface);
 
+  if (wl_surface_get_version (impl->display_server.wl_surface) >= WL_SURFACE_OFFSET_SINCE_VERSION)
+    wl_surface_offset (impl->display_server.wl_surface, dx, dy);
+
   GDK_DRAW_CONTEXT_CLASS (gdk_wayland_vulkan_context_parent_class)->end_frame (context, painted);
 
   gdk_wayland_surface_notify_committed (surface);
@@ -77,16 +76,8 @@ static void
 gdk_vulkan_context_wayland_empty_frame (GdkDrawContext *context)
 {
   GdkSurface *surface = gdk_draw_context_get_surface (GDK_DRAW_CONTEXT (context));
-  GdkWaylandSurface *impl = GDK_WAYLAND_SURFACE (surface);
 
-  if (!impl->has_pending_subsurface_commits)
-    return;
-
-  gdk_wayland_surface_sync (surface);
-  gdk_wayland_surface_request_frame (surface);
-
-  gdk_wayland_surface_commit (surface);
-  gdk_wayland_surface_notify_committed (surface);
+  gdk_wayland_surface_handle_empty_frame (surface);
 }
 
 static void
