@@ -246,7 +246,7 @@ gtk_at_context_class_init (GtkATContextClass *klass)
   klass->update_text_contents = gtk_at_context_real_update_text_contents;
 
   /**
-   * GtkATContext:accessible-role: (attributes org.gtk.Property.get=gtk_at_context_get_accessible_role)
+   * GtkATContext:accessible-role:
    *
    * The accessible role used by the AT context.
    *
@@ -262,7 +262,7 @@ gtk_at_context_class_init (GtkATContextClass *klass)
                        G_PARAM_STATIC_STRINGS);
 
   /**
-   * GtkATContext:accessible: (attributes org.gtk.Property.get=gtk_at_context_get_accessible)
+   * GtkATContext:accessible:
    *
    * The `GtkAccessible` that created the `GtkATContext` instance.
    */
@@ -328,6 +328,7 @@ static const char *property_attrs[] = {
   [GTK_ACCESSIBLE_PROPERTY_VALUE_MIN]           = "valuemin",
   [GTK_ACCESSIBLE_PROPERTY_VALUE_NOW]           = "valuenow",
   [GTK_ACCESSIBLE_PROPERTY_VALUE_TEXT]          = "valuetext",
+  [GTK_ACCESSIBLE_PROPERTY_HELP_TEXT]           = "helptext",
 };
 
 /*< private >
@@ -342,7 +343,7 @@ const char *
 gtk_accessible_property_get_attribute_name (GtkAccessibleProperty property)
 {
   g_return_val_if_fail (property >= GTK_ACCESSIBLE_PROPERTY_AUTOCOMPLETE &&
-                        property <= GTK_ACCESSIBLE_PROPERTY_VALUE_TEXT,
+                        property <= GTK_ACCESSIBLE_PROPERTY_HELP_TEXT,
                         "<none>");
 
   return property_attrs[property];
@@ -437,7 +438,7 @@ gtk_at_context_init (GtkATContext *self)
 }
 
 /**
- * gtk_at_context_get_accessible: (attributes org.gtk.Method.get_property=accessible)
+ * gtk_at_context_get_accessible:
  * @self: a `GtkATContext`
  *
  * Retrieves the `GtkAccessible` using this context.
@@ -477,7 +478,7 @@ gtk_at_context_set_accessible_role (GtkATContext      *self,
 }
 
 /**
- * gtk_at_context_get_accessible_role: (attributes org.gtk.Method.get_property=accessible-role)
+ * gtk_at_context_get_accessible_role:
  * @self: a `GtkATContext`
  *
  * Retrieves the accessible role of this context.
